@@ -1,13 +1,17 @@
+# Copyright FuseSoC contributors
+# Licensed under the 2-Clause BSD License, see LICENSE for details.
+# SPDX-License-Identifier: BSD-2-Clause
+
 import logging
+import warnings
 
 from fusesoc.capi1.core import Core as Capi1Core
 from fusesoc.capi2.core import Core as Capi2Core
 
-
 logger = logging.getLogger(__name__)
 
 
-class Core(object):
+class Core:
     def __new__(cls, *args, **kwargs):
         with open(args[0]) as f:
             l = f.readline().split()
@@ -16,6 +20,12 @@ class Core(object):
             else:
                 first_line = ""
             if first_line == "CAPI=1":
+                warnings.warn(
+                    "The CAPI1 core file description format is deprecated and "
+                    "will be removed in the next major version of FuseSoC. "
+                    "Please port your core files to the CAPI2 format.",
+                    FutureWarning,
+                )
                 return Capi1Core(*args, **kwargs)
             elif first_line == "CAPI=2:":
                 return Capi2Core(*args, **kwargs)
