@@ -2,20 +2,19 @@
 # Licensed under the 2-Clause BSD License, see LICENSE for details.
 # SPDX-License-Identifier: BSD-2-Clause
 
-import subprocess
 import logging
+import subprocess
 import sys
-import importlib
+import warnings
 
 import yaml
 
 try:
-    from yaml import CSafeLoader as YamlLoader, CSafeDumper as YamlDumper
+    from yaml import CSafeDumper as YamlDumper
+    from yaml import CSafeLoader as YamlLoader
 except ImportError:
-    from yaml import SafeLoader as YamlLoader, SafeDumper as YamlDumper
-
-if sys.version[0] == "2":
-    FileNotFoundError = OSError
+    from yaml import SafeDumper as YamlDumper
+    from yaml import SafeLoader as YamlLoader
 
 logger = logging.getLogger(__name__)
 
@@ -27,12 +26,14 @@ class Launcher:
         self.cwd = cwd
 
     def run(self):
-        """Runs the cmd with args after converting them all to strings via str
-        """
+        """Runs the cmd with args after converting them all to strings via str"""
         logger.debug(self.cwd)
         logger.debug("    " + str(self))
         try:
-            subprocess.check_call(map(str, [self.cmd] + self.args), cwd=self.cwd,),
+            subprocess.check_call(
+                map(str, [self.cmd] + self.args),
+                cwd=self.cwd,
+            ),
         except FileNotFoundError:
             raise RuntimeError(
                 "Command '" + self.cmd + "' not found. Make sure it is in $PATH"
@@ -106,6 +107,22 @@ def setup_logging(level, monchrome=False, log_file=None):
     if log_file:
         logging.basicConfig(filename=log_file, filemode="w", level=logging.DEBUG)
 
+    # Redirect Python warnings (from the warnings module) to the standard
+    # logging infrastructure. Warnings end up in the py.warnings category.
+    logging.captureWarnings(True)
+
+    def _formatwarning(message, category, filename, lineno, line=None):
+        # Format FutureWarnings, which are intended for end users, in a way
+        # that strips out all code references, which are meaningless to an end
+        # user.
+        if category == FutureWarning:
+            return message
+
+        return _formatwarning_orig(message, category, filename, lineno, line)
+
+    _formatwarning_orig = warnings.formatwarning
+    warnings.formatwarning = _formatwarning
+
     # Pretty color terminal logging
     ch = logging.StreamHandler()
     ch.setLevel(logging.DEBUG)
@@ -116,17 +133,18 @@ def setup_logging(level, monchrome=False, log_file=None):
         "__main__",
         "fusesoc",
         "edalize",
+        "py.warnings",
     )
     for package in packages:
-        logger = logging.getLogger(package)
-        logger.addHandler(ch)
-        logger.setLevel(level)
+        package_logger = logging.getLogger(package)
+        package_logger.addHandler(ch)
+        package_logger.setLevel(level)
     # Warning only packages
     warning_only_packages = []
     for package in warning_only_packages:
-        logger = logging.getLogger(package)
-        logger.addHandler(ch)
-        logger.setLevel(logging.WARNING)
+        package_logger = logging.getLogger(package)
+        package_logger.addHandler(ch)
+        package_logger.setLevel(logging.WARNING)
     logger.debug("Setup logging at level {}.".format(level))
 
 
